Stormbot fortune plugin
=======================

This is a Stormbot_ plugin that tell random fortune::

    <master>   | stormbot: fortune
    <stormbot> | Il faut pas respirer la compote, ça fait tousser.

.. _Stormbot: https://pypi.org/project/stormbot

Install
=======

::

    pip install stormbot-fortune

Example
=======

::

    stormbot --plugins stormbot_fortune.fortune
